@@ -13,7 +13,7 @@ impl PyError {
         PyError(String::from(s))
     }
     pub fn into_pyerr<T: PyTypeInfo>(self) -> PyErr {
-        PyErr::new::<T, _>(format!("{}", self))
+        PyErr::new::<T, _>(format!("{self}"))
     }
 }
 impl Display for PyError {
@@ -26,7 +26,7 @@ impl std::error::Error for PyError {}
 pub struct ToPyResult<T>(pub Result<T>);
 impl<T> From<ToPyResult<T>> for PyResult<T> {
     fn from(v: ToPyResult<T>) -> Self {
-        v.0.map_err(|e| exceptions::PyException::new_err(format!("{}", e)))
+        v.0.map_err(|e| exceptions::PyException::new_err(format!("{e}")))
     }
 }
 impl<T> ToPyResult<T> {
@@ -37,6 +37,6 @@ impl<T> ToPyResult<T> {
 
 pub(crate) fn deprecation_warning(py: Python<'_>, version: &str, message: &str) -> PyResult<()> {
     let deprecation_warning = py.import("builtins")?.getattr("DeprecationWarning")?;
-    let full_message = format!("Deprecated in {}: {}", version, message);
+    let full_message = format!("Deprecated in {version}: {message}");
     pyo3::PyErr::warn(py, &deprecation_warning, &CString::new(full_message)?, 0)
 }
