@@ -1,17 +1,20 @@
 use std::convert::TryInto;
 use std::sync::Arc;
-
-use pyo3::exceptions;
-use pyo3::prelude::*;
-use pyo3::types::*;
+use std::sync::RwLock;
 
 use crate::encoding::PyEncoding;
 use crate::error::ToPyResult;
+use pyo3::exceptions;
+use pyo3::exceptions::PyException;
+use pyo3::prelude::*;
+use pyo3::types::*;
+use serde::ser::SerializeStruct;
+use serde::Deserializer;
+use serde::Serializer;
 use serde::{Deserialize, Serialize};
 use tk::processors::bert::BertProcessing;
 use tk::processors::byte_level::ByteLevel;
 use tk::processors::roberta::RobertaProcessing;
-use tk::processors::sequence::Sequence;
 use tk::processors::template::{SpecialToken, Template};
 use tk::processors::PostProcessorWrapper;
 use tk::{Encoding, PostProcessor};
@@ -30,42 +33,67 @@ use tokenizers as tk;
 #[derive(Clone, Deserialize, Serialize)]
 #[serde(transparent)]
 pub struct PyPostProcessor {
-    pub processor: Arc<PostProcessorWrapper>,
+    processor: PyPostProcessorTypeWrapper,
+}
+
+impl<I> From<I> for PyPostProcessor
+where
+    I: Into<PostProcessorWrapper>,
+{
+    fn from(processor: I) -> Self {
+        PyPostProcessor {
+            processor: processor.into().into(),
+        }
+    }
 }
 
 impl PyPostProcessor {
-    pub fn new(processor: Arc<PostProcessorWrapper>) -> Self {
+    pub(crate) fn new(processor: PyPostProcessorTypeWrapper) -> Self {
         PyPostProcessor { processor }
     }
 
     pub(crate) fn get_as_subtype(&self, py: Python<'_>) -> PyResult<PyObject> {
         let base = self.clone();
-        Ok(match self.processor.as_ref() {
-            PostProcessorWrapper::ByteLevel(_) => Py::new(py, (PyByteLevel {}, base))?
+        Ok(
+            match self.processor {
+                PyPostProcessorTypeWrapper::Sequence(_) => Py::new(py, (PySequence {}, base))?
                 .into_pyobject(py)?
                 .into_any()
                 .into(),
-            PostProcessorWrapper::Bert(_) => Py::new(py, (PyBertProcessing {}, base))?
-                .into_pyobject(py)?
-                .into_any()
-                .into(),
-            PostProcessorWrapper::Roberta(_) => Py::new(py, (PyRobertaProcessing {}, base))?
-                .into_pyobject(py)?
-                .into_any()
-                .into(),
-            PostProcessorWrapper::Template(_) => Py::new(py, (PyTemplateProcessing {}, base))?
-                .into_pyobject(py)?
-                .into_any()
-                .into(),
-            PostProcessorWrapper::Sequence(_) => Py::new(py, (PySequence {}, base))?
-                .into_pyobject(py)?
-                .into_any()
-                .into(),
-        })
+                PyPostProcessorTypeWrapper::Single(ref inner) => {
+
+            match &*inner.read().map_err(|_| {
+                PyException::new_err("RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor")
+            })? {
+                PostProcessorWrapper::ByteLevel(_) => Py::new(py, (PyByteLevel {}, base))?
+                    .into_pyobject(py)?
+                    .into_any()
+                    .into(),
+                PostProcessorWrapper::Bert(_) => Py::new(py, (PyBertProcessing {}, base))?
+                    .into_pyobject(py)?
+                    .into_any()
+                    .into(),
+                PostProcessorWrapper::Roberta(_) => Py::new(py, (PyRobertaProcessing {}, base))?
+                    .into_pyobject(py)?
+                    .into_any()
+                    .into(),
+                PostProcessorWrapper::Template(_) => Py::new(py, (PyTemplateProcessing {}, base))?
+                    .into_pyobject(py)?
+                    .into_any()
+                    .into(),
+                PostProcessorWrapper::Sequence(_) => Py::new(py, (PySequence {}, base))?
+                    .into_pyobject(py)?
+                    .into_any()
+                    .into(),
+            }
+                }
+            }
+        )
     }
 }
 
 impl PostProcessor for PyPostProcessor {
+    // TODO: update signature to `tk::Result<usize>`
     fn added_tokens(&self, is_pair: bool) -> usize {
         self.processor.added_tokens(is_pair)
     }
@@ -83,10 +111,9 @@ impl PostProcessor for PyPostProcessor {
 #[pymethods]
 impl PyPostProcessor {
     fn __getstate__(&self, py: Python) -> PyResult<PyObject> {
-        let data = serde_json::to_string(self.processor.as_ref()).map_err(|e| {
+        let data = serde_json::to_string(&self.processor).map_err(|e| {
             exceptions::PyException::new_err(format!(
-                "Error while attempting to pickle PostProcessor: {}",
-                e
+                "Error while attempting to pickle PostProcessor: {e}"
             ))
         })?;
         Ok(PyBytes::new(py, data.as_bytes()).into())
@@ -97,8 +124,7 @@ impl PyPostProcessor {
             Ok(s) => {
                 self.processor = serde_json::from_slice(s).map_err(|e| {
                     exceptions::PyException::new_err(format!(
-                        "Error while attempting to unpickle PostProcessor: {}",
-                        e
+                        "Error while attempting to unpickle PostProcessor: {e}"
                     ))
                 })?;
                 Ok(())
@@ -116,8 +142,8 @@ impl PyPostProcessor {
     /// Returns:
     ///     :obj:`int`: The number of tokens to add
     #[pyo3(text_signature = "(self, is_pair)")]
-    fn num_special_tokens_to_add(&self, is_pair: bool) -> usize {
-        self.processor.added_tokens(is_pair)
+    fn num_special_tokens_to_add(&self, is_pair: bool) -> PyResult<usize> {
+        Ok(self.processor.added_tokens(is_pair))
     }
 
     /// Post-process the given encodings, generating the final one
@@ -162,6 +188,132 @@ impl PyPostProcessor {
     }
 }
 
+macro_rules! getter {
+    ($self: ident, $variant: ident, $($name: tt)+) => {{
+        let super_ = $self.as_ref();
+        if let PyPostProcessorTypeWrapper::Single(ref single) = super_.processor {
+            if let PostProcessorWrapper::$variant(ref post) = *single.read().expect(
+                "RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor"
+            ) {
+                post.$($name)+
+            } else {
+                unreachable!()
+            }
+        } else {
+            unreachable!()
+        }
+    }};
+}
+
+macro_rules! setter {
+    ($self: ident, $variant: ident, $name: ident, $value: expr) => {{
+        let super_ = $self.as_ref();
+        if let PyPostProcessorTypeWrapper::Single(ref single) = super_.processor {
+        if let PostProcessorWrapper::$variant(ref mut post) = *single.write().expect(
+            "RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor",
+        ) {
+            post.$name = $value;
+        }
+        }
+    }};
+    ($self: ident, $variant: ident, @$name: ident, $value: expr) => {{
+        let super_ = $self.as_ref();
+        if let PyPostProcessorTypeWrapper::Single(ref single) = super_.processor {
+        if let PostProcessorWrapper::$variant(ref mut post) = *single.write().expect(
+            "RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor",
+        ) {
+            post.$name($value);
+        }
+        }
+    };};
+}
+
+#[derive(Clone)]
+pub(crate) enum PyPostProcessorTypeWrapper {
+    Sequence(Vec<Arc<RwLock<PostProcessorWrapper>>>),
+    Single(Arc<RwLock<PostProcessorWrapper>>),
+}
+
+impl PostProcessor for PyPostProcessorTypeWrapper {
+    fn added_tokens(&self, is_pair: bool) -> usize {
+        match self {
+            PyPostProcessorTypeWrapper::Single(inner) => inner
+                .read()
+                .expect("RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor")
+                .added_tokens(is_pair),
+            PyPostProcessorTypeWrapper::Sequence(inner) => inner.iter().map(|p| {
+                p.read()
+                    .expect("RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor")
+                    .added_tokens(is_pair)
+            }).sum::<usize>(),
+        }
+    }
+
+    fn process_encodings(
+        &self,
+        mut encodings: Vec<Encoding>,
+        add_special_tokens: bool,
+    ) -> tk::Result<Vec<Encoding>> {
+        match self {
+            PyPostProcessorTypeWrapper::Single(inner) => inner
+                .read()
+                .map_err(|_| PyException::new_err("RwLock synchronisation primitive is poisoned, cannot get subtype of PyPreTokenizer"))?
+                .process_encodings(encodings, add_special_tokens),
+            PyPostProcessorTypeWrapper::Sequence(inner) => {
+                for processor in inner.iter() {
+                    encodings = processor
+                        .read()
+                        .map_err(|_| PyException::new_err("RwLock synchronisation primitive is poisoned, cannot get subtype of PyPreTokenizer"))?
+                        .process_encodings(encodings, add_special_tokens)?;
+                }
+        Ok(encodings)
+            },
+        }
+    }
+}
+
+impl<'de> Deserialize<'de> for PyPostProcessorTypeWrapper {
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        let wrapper = PostProcessorWrapper::deserialize(deserializer)?;
+        Ok(wrapper.into())
+    }
+}
+
+impl Serialize for PyPostProcessorTypeWrapper {
+    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        match self {
+            PyPostProcessorTypeWrapper::Sequence(seq) => {
+                let mut ser = serializer.serialize_struct("Sequence", 2)?;
+                ser.serialize_field("type", "Sequence")?;
+                ser.serialize_field("processors", seq)?;
+                ser.end()
+            }
+            PyPostProcessorTypeWrapper::Single(inner) => inner.serialize(serializer),
+        }
+    }
+}
+
+impl<I> From<I> for PyPostProcessorTypeWrapper
+where
+    I: Into<PostProcessorWrapper>,
+{
+    fn from(processor: I) -> Self {
+        let processor = processor.into();
+        match processor {
+            PostProcessorWrapper::Sequence(seq) => PyPostProcessorTypeWrapper::Sequence(
+                seq.into_iter().map(|p| Arc::new(RwLock::new(p))).collect(),
+            ),
+            _ => PyPostProcessorTypeWrapper::Single(Arc::new(RwLock::new(processor.clone()))),
+        }
+    }
+}
+
 /// This post-processor takes care of adding the special tokens needed by
 /// a Bert model:
 ///
@@ -181,15 +333,46 @@ impl PyBertProcessing {
     #[new]
     #[pyo3(text_signature = "(self, sep, cls)")]
     fn new(sep: (String, u32), cls: (String, u32)) -> (Self, PyPostProcessor) {
-        (
-            PyBertProcessing {},
-            PyPostProcessor::new(Arc::new(BertProcessing::new(sep, cls).into())),
-        )
+        (PyBertProcessing {}, BertProcessing::new(sep, cls).into())
     }
 
     fn __getnewargs__<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyTuple>> {
         PyTuple::new(py, [("", 0), ("", 0)])
     }
+
+    #[getter]
+    fn get_sep(self_: PyRef<Self>) -> Result<Bound<'_, PyTuple>, PyErr> {
+        let py = self_.py();
+        let (tok, id) = getter!(self_, Bert, get_sep_copy());
+        PyTuple::new(
+            py,
+            Vec::<PyObject>::from([tok.into_pyobject(py)?.into(), id.into_pyobject(py)?.into()]),
+        )
+    }
+
+    #[setter]
+    fn set_sep(self_: PyRef<Self>, sep: Bound<'_, PyTuple>) -> PyResult<()> {
+        let sep = sep.extract()?;
+        setter!(self_, Bert, sep, sep);
+        Ok(())
+    }
+
+    #[getter]
+    fn get_cls(self_: PyRef<Self>) -> Result<Bound<'_, PyTuple>, PyErr> {
+        let py = self_.py();
+        let (tok, id) = getter!(self_, Bert, get_cls_copy());
+        PyTuple::new(
+            py,
+            Vec::<PyObject>::from([tok.into_pyobject(py)?.into(), id.into_pyobject(py)?.into()]),
+        )
+    }
+
+    #[setter]
+    fn set_cls(self_: PyRef<Self>, cls: Bound<'_, PyTuple>) -> PyResult<()> {
+        let cls = cls.extract()?;
+        setter!(self_, Bert, cls, cls);
+        Ok(())
+    }
 }
 
 /// This post-processor takes care of adding the special tokens needed by
@@ -231,15 +414,66 @@ impl PyRobertaProcessing {
         let proc = RobertaProcessing::new(sep, cls)
             .trim_offsets(trim_offsets)
             .add_prefix_space(add_prefix_space);
-        (
-            PyRobertaProcessing {},
-            PyPostProcessor::new(Arc::new(proc.into())),
-        )
+        (PyRobertaProcessing {}, proc.into())
     }
 
     fn __getnewargs__<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyTuple>> {
         PyTuple::new(py, [("", 0), ("", 0)])
     }
+
+    #[getter]
+    fn get_sep(self_: PyRef<Self>) -> Result<Bound<'_, PyTuple>, PyErr> {
+        let py = self_.py();
+        let (tok, id) = getter!(self_, Roberta, get_sep_copy());
+        PyTuple::new(
+            py,
+            Vec::<PyObject>::from([tok.into_pyobject(py)?.into(), id.into_pyobject(py)?.into()]),
+        )
+    }
+
+    #[setter]
+    fn set_sep(self_: PyRef<Self>, sep: Bound<'_, PyTuple>) -> PyResult<()> {
+        let sep = sep.extract()?;
+        setter!(self_, Roberta, sep, sep);
+        Ok(())
+    }
+
+    #[getter]
+    fn get_cls(self_: PyRef<Self>) -> Result<Bound<'_, PyTuple>, PyErr> {
+        let py = self_.py();
+        let (tok, id) = getter!(self_, Roberta, get_cls_copy());
+        PyTuple::new(
+            py,
+            Vec::<PyObject>::from([tok.into_pyobject(py)?.into(), id.into_pyobject(py)?.into()]),
+        )
+    }
+
+    #[setter]
+    fn set_cls(self_: PyRef<Self>, cls: Bound<'_, PyTuple>) -> PyResult<()> {
+        let cls = cls.extract()?;
+        setter!(self_, Roberta, cls, cls);
+        Ok(())
+    }
+
+    #[getter]
+    fn get_trim_offsets(self_: PyRef<Self>) -> bool {
+        getter!(self_, Roberta, trim_offsets)
+    }
+
+    #[setter]
+    fn set_trim_offsets(self_: PyRef<Self>, trim_offsets: bool) {
+        setter!(self_, Roberta, trim_offsets, trim_offsets)
+    }
+
+    #[getter]
+    fn get_add_prefix_space(self_: PyRef<Self>) -> bool {
+        getter!(self_, Roberta, add_prefix_space)
+    }
+
+    #[setter]
+    fn set_add_prefix_space(self_: PyRef<Self>, add_prefix_space: bool) {
+        setter!(self_, Roberta, add_prefix_space, add_prefix_space)
+    }
 }
 
 /// This post-processor takes care of trimming the offsets.
@@ -255,21 +489,58 @@ pub struct PyByteLevel {}
 #[pymethods]
 impl PyByteLevel {
     #[new]
-    #[pyo3(signature = (trim_offsets = None, **_kwargs), text_signature = "(self, trim_offsets=True)")]
+    #[pyo3(signature = (add_prefix_space = None, trim_offsets = None, use_regex = None, **_kwargs), text_signature = "(self, trim_offsets=True)")]
     fn new(
+        add_prefix_space: Option<bool>,
         trim_offsets: Option<bool>,
+        use_regex: Option<bool>,
         _kwargs: Option<&Bound<'_, PyDict>>,
     ) -> (Self, PyPostProcessor) {
         let mut byte_level = ByteLevel::default();
 
+        if let Some(aps) = add_prefix_space {
+            byte_level = byte_level.add_prefix_space(aps);
+        }
+
         if let Some(to) = trim_offsets {
             byte_level = byte_level.trim_offsets(to);
         }
 
-        (
-            PyByteLevel {},
-            PyPostProcessor::new(Arc::new(byte_level.into())),
-        )
+        if let Some(ur) = use_regex {
+            byte_level = byte_level.use_regex(ur);
+        }
+
+        (PyByteLevel {}, byte_level.into())
+    }
+
+    #[getter]
+    fn get_add_prefix_space(self_: PyRef<Self>) -> bool {
+        getter!(self_, ByteLevel, add_prefix_space)
+    }
+
+    #[setter]
+    fn set_add_prefix_space(self_: PyRef<Self>, add_prefix_space: bool) {
+        setter!(self_, ByteLevel, add_prefix_space, add_prefix_space)
+    }
+
+    #[getter]
+    fn get_trim_offsets(self_: PyRef<Self>) -> bool {
+        getter!(self_, ByteLevel, trim_offsets)
+    }
+
+    #[setter]
+    fn set_trim_offsets(self_: PyRef<Self>, trim_offsets: bool) {
+        setter!(self_, ByteLevel, trim_offsets, trim_offsets)
+    }
+
+    #[getter]
+    fn get_use_regex(self_: PyRef<Self>) -> bool {
+        getter!(self_, ByteLevel, use_regex)
+    }
+
+    #[setter]
+    fn set_use_regex(self_: PyRef<Self>, use_regex: bool) {
+        setter!(self_, ByteLevel, use_regex, use_regex)
     }
 }
 
@@ -430,10 +701,26 @@ impl PyTemplateProcessing {
             .build()
             .map_err(|e| exceptions::PyValueError::new_err(e.to_string()))?;
 
-        Ok((
-            PyTemplateProcessing {},
-            PyPostProcessor::new(Arc::new(processor.into())),
-        ))
+        Ok((PyTemplateProcessing {}, processor.into()))
+    }
+
+    #[getter]
+    fn get_single(self_: PyRef<Self>) -> String {
+        getter!(self_, Template, get_single())
+    }
+
+    #[setter]
+    fn set_single(self_: PyRef<Self>, single: PyTemplate) -> PyResult<()> {
+        let template: Template = Template::from(single);
+        let super_ = self_.as_ref();
+        if let PyPostProcessorTypeWrapper::Single(ref inner) = super_.processor {
+            if let PostProcessorWrapper::Template(ref mut post) = *inner
+                .write()
+                .map_err(|_| PyException::new_err("RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor"))? {
+                post.set_single(template);
+            }
+        }
+        Ok(())
     }
 }
 
@@ -444,27 +731,79 @@ impl PyTemplateProcessing {
 ///         The processors that need to be chained
 #[pyclass(extends=PyPostProcessor, module = "tokenizers.processors", name = "Sequence")]
 pub struct PySequence {}
+
 #[pymethods]
 impl PySequence {
     #[new]
     #[pyo3(signature = (processors_py), text_signature = "(self, processors)")]
-    fn new(processors_py: &Bound<'_, PyList>) -> (Self, PyPostProcessor) {
-        let mut processors: Vec<PostProcessorWrapper> = Vec::with_capacity(processors_py.len());
+    fn new(processors_py: &Bound<'_, PyList>) -> PyResult<(Self, PyPostProcessor)> {
+        let mut processors = Vec::with_capacity(processors_py.len());
         for n in processors_py.iter() {
-            let processor: PyRef<PyPostProcessor> = n.extract().unwrap();
-            let processor = processor.processor.as_ref();
-            processors.push(processor.clone());
+            let processor: PyRef<PyPostProcessor> = n.extract()?;
+            match &processor.processor {
+                PyPostProcessorTypeWrapper::Sequence(inner) => {
+                    processors.extend(inner.iter().cloned())
+                }
+                PyPostProcessorTypeWrapper::Single(inner) => processors.push(inner.clone()),
+            }
         }
-        let sequence_processor = Sequence::new(processors);
-        (
+        Ok((
             PySequence {},
-            PyPostProcessor::new(Arc::new(PostProcessorWrapper::Sequence(sequence_processor))),
-        )
+            PyPostProcessor::new(PyPostProcessorTypeWrapper::Sequence(processors)),
+        ))
     }
 
     fn __getnewargs__<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyTuple>> {
         PyTuple::new(py, [PyList::empty(py)])
     }
+
+    fn __getitem__(self_: PyRef<'_, Self>, py: Python<'_>, index: usize) -> PyResult<Py<PyAny>> {
+        match &self_.as_ref().processor {
+            PyPostProcessorTypeWrapper::Sequence(ref inner) => match inner.get(index) {
+                Some(item) => {
+                    PyPostProcessor::new(PyPostProcessorTypeWrapper::Single(item.clone()))
+                        .get_as_subtype(py)
+                }
+                _ => Err(PyErr::new::<pyo3::exceptions::PyIndexError, _>(
+                    "Index not found",
+                )),
+            },
+            _ => Err(PyErr::new::<pyo3::exceptions::PyIndexError, _>(
+                "This processor is not a Sequence, it does not support __getitem__",
+            )),
+        }
+    }
+
+    fn __setitem__(self_: PyRef<'_, Self>, index: usize, value: Bound<'_, PyAny>) -> PyResult<()> {
+        let processor: PyPostProcessor = value.extract()?;
+        let PyPostProcessorTypeWrapper::Single(processor) = processor.processor else {
+            return Err(PyException::new_err("processor should not be a sequence"));
+        };
+
+        match &self_.as_ref().processor {
+            PyPostProcessorTypeWrapper::Sequence(inner) => match inner.get(index) {
+                Some(item) => {
+                    *item
+                        .write()
+                        .map_err(|_| PyException::new_err("RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor"))? = processor
+                        .read()
+                        .map_err(|_| PyException::new_err("RwLock synchronisation primitive is poisoned, cannot get subtype of PyPostProcessor"))?
+                        .clone();
+                }
+                _ => {
+                    return Err(PyErr::new::<pyo3::exceptions::PyIndexError, _>(
+                        "Index not found",
+                    ))
+                }
+            },
+            _ => {
+                return Err(PyException::new_err(
+                    "This processor is not a Sequence, it does not support __setitem__",
+                ))
+            }
+        };
+        Ok(())
+    }
 }
 
 /// Processors Module
@@ -481,20 +820,20 @@ pub fn processors(m: &Bound<'_, PyModule>) -> PyResult<()> {
 
 #[cfg(test)]
 mod test {
-    use std::sync::Arc;
+    use std::sync::{Arc, RwLock};
 
     use pyo3::prelude::*;
     use tk::processors::bert::BertProcessing;
     use tk::processors::PostProcessorWrapper;
 
-    use crate::processors::PyPostProcessor;
+    use crate::processors::{PyPostProcessor, PyPostProcessorTypeWrapper};
 
     #[test]
     fn get_subtype() {
         Python::with_gil(|py| {
-            let py_proc = PyPostProcessor::new(Arc::new(
-                BertProcessing::new(("SEP".into(), 0), ("CLS".into(), 1)).into(),
-            ));
+            let py_proc = PyPostProcessor::new(PyPostProcessorTypeWrapper::Single(Arc::new(
+                RwLock::new(BertProcessing::new(("SEP".into(), 0), ("CLS".into(), 1)).into()),
+            )));
             let py_bert = py_proc.get_as_subtype(py).unwrap();
             assert_eq!(
                 "BertProcessing",
@@ -510,21 +849,29 @@ mod test {
         let rs_processing_ser = serde_json::to_string(&rs_processing).unwrap();
         let rs_wrapper_ser = serde_json::to_string(&rs_wrapper).unwrap();
 
-        let py_processing = PyPostProcessor::new(Arc::new(rs_wrapper));
+        let py_processing = PyPostProcessor::new(PyPostProcessorTypeWrapper::Single(Arc::new(
+            RwLock::new(rs_wrapper),
+        )));
         let py_ser = serde_json::to_string(&py_processing).unwrap();
         assert_eq!(py_ser, rs_processing_ser);
         assert_eq!(py_ser, rs_wrapper_ser);
 
         let py_processing: PyPostProcessor = serde_json::from_str(&rs_processing_ser).unwrap();
-        match py_processing.processor.as_ref() {
-            PostProcessorWrapper::Bert(_) => (),
-            _ => panic!("Expected Bert postprocessor."),
+        match py_processing.processor {
+            PyPostProcessorTypeWrapper::Single(inner) => match *inner.as_ref().read().unwrap() {
+                PostProcessorWrapper::Bert(_) => (),
+                _ => panic!("Expected Bert postprocessor."),
+            },
+            _ => panic!("Expected a single processor, got a sequence"),
         }
 
         let py_processing: PyPostProcessor = serde_json::from_str(&rs_wrapper_ser).unwrap();
-        match py_processing.processor.as_ref() {
-            PostProcessorWrapper::Bert(_) => (),
-            _ => panic!("Expected Bert postprocessor."),
-        }
+        match py_processing.processor {
+            PyPostProcessorTypeWrapper::Single(inner) => match *inner.as_ref().read().unwrap() {
+                PostProcessorWrapper::Bert(_) => (),
+                _ => panic!("Expected Bert postprocessor."),
+            },
+            _ => panic!("Expected a single processor, got a sequence"),
+        };
     }
 }
