@@ -100,7 +100,7 @@ impl PyAddedToken {
     }
 
     pub fn as_pydict<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyDict>> {
-        let dict = PyDict::new_bound(py);
+        let dict = PyDict::new(py);
         let token = self.get_token();
 
         dict.set_item("content", token.content)?;
@@ -143,7 +143,7 @@ impl PyAddedToken {
                     "rstrip" => token.rstrip = Some(value.extract()?),
                     "normalized" => token.normalized = Some(value.extract()?),
                     "special" => token.special = value.extract()?,
-                    _ => println!("Ignored unknown kwarg option {}", key),
+                    _ => println!("Ignored unknown kwarg option {key}"),
                 }
             }
         }
@@ -347,6 +347,7 @@ impl From<PyArrayUnicode> for tk::InputSequence<'_> {
 }
 
 struct PyArrayStr(Vec<String>);
+
 impl FromPyObject<'_> for PyArrayStr {
     fn extract_bound(ob: &Bound<'_, PyAny>) -> PyResult<Self> {
         let array = ob.downcast::<PyArray1<PyObject>>()?;
@@ -491,11 +492,10 @@ impl PyTokenizer {
     fn __getstate__(&self, py: Python) -> PyResult<PyObject> {
         let data = serde_json::to_string(&self.tokenizer).map_err(|e| {
             exceptions::PyException::new_err(format!(
-                "Error while attempting to pickle Tokenizer: {}",
-                e
+                "Error while attempting to pickle Tokenizer: {e}"
             ))
         })?;
-        Ok(PyBytes::new_bound(py, data.as_bytes()).to_object(py))
+        Ok(PyBytes::new(py, data.as_bytes()).into())
     }
 
     fn __setstate__(&mut self, py: Python, state: PyObject) -> PyResult<()> {
@@ -503,8 +503,7 @@ impl PyTokenizer {
             Ok(s) => {
                 self.tokenizer = serde_json::from_slice(s).map_err(|e| {
                     exceptions::PyException::new_err(format!(
-                        "Error while attempting to unpickle Tokenizer: {}",
-                        e
+                        "Error while attempting to unpickle Tokenizer: {e}"
                     ))
                 })?;
                 Ok(())
@@ -513,9 +512,12 @@ impl PyTokenizer {
         }
     }
 
-    fn __getnewargs__<'p>(&self, py: Python<'p>) -> Bound<'p, PyTuple> {
-        let model = PyModel::from(BPE::default()).into_py(py);
-        PyTuple::new_bound(py, vec![model])
+    fn __getnewargs__<'p>(&self, py: Python<'p>) -> PyResult<Bound<'p, PyTuple>> {
+        let model: PyObject = PyModel::from(BPE::default())
+            .into_pyobject(py)?
+            .into_any()
+            .into();
+        PyTuple::new(py, vec![model])
     }
 
     /// Instantiate a new :class:`~tokenizers.Tokenizer` from the given JSON string.
@@ -563,8 +565,7 @@ impl PyTokenizer {
     fn from_buffer(buffer: &Bound<'_, PyBytes>) -> PyResult<Self> {
         let tokenizer = serde_json::from_slice(buffer.as_bytes()).map_err(|e| {
             exceptions::PyValueError::new_err(format!(
-                "Cannot instantiate Tokenizer from buffer: {}",
-                e
+                "Cannot instantiate Tokenizer from buffer: {e}"
             ))
         })?;
         Ok(Self { tokenizer })
@@ -594,14 +595,14 @@ impl PyTokenizer {
         token: Option<String>,
     ) -> PyResult<Self> {
         let path = Python::with_gil(|py| -> PyResult<String> {
-            let huggingface_hub = PyModule::import_bound(py, intern!(py, "huggingface_hub"))?;
+            let huggingface_hub = PyModule::import(py, intern!(py, "huggingface_hub"))?;
             let hf_hub_download = huggingface_hub.getattr(intern!(py, "hf_hub_download"))?;
             let kwargs = [
                 (intern!(py, "repo_id"), identifier),
                 (intern!(py, "filename"), "tokenizer.json"),
                 (intern!(py, "revision"), &revision),
             ]
-            .into_py_dict_bound(py);
+            .into_py_dict(py)?;
             if let Some(token) = token {
                 kwargs.set_item(intern!(py, "token"), token)?;
             }
@@ -747,9 +748,8 @@ impl PyTokenizer {
                             "only_first" => Ok(TruncationStrategy::OnlyFirst),
                             "only_second" => Ok(TruncationStrategy::OnlySecond),
                             _ => Err(PyError(format!(
-                                "Unknown `strategy`: `{}`. Use \
-                                 one of `longest_first`, `only_first`, or `only_second`",
-                                value
+                                "Unknown `strategy`: `{value}`. Use \
+                                 one of `longest_first`, `only_first`, or `only_second`"
                             ))
                             .into_pyerr::<exceptions::PyValueError>()),
                         }?
@@ -760,14 +760,13 @@ impl PyTokenizer {
                             "left" => Ok(TruncationDirection::Left),
                             "right" => Ok(TruncationDirection::Right),
                             _ => Err(PyError(format!(
-                                "Unknown `direction`: `{}`. Use \
-                                 one of `left` or `right`.",
-                                value
+                                "Unknown `direction`: `{value}`. Use \
+                                 one of `left` or `right`."
                             ))
                             .into_pyerr::<exceptions::PyValueError>()),
                         }?
                     }
-                    _ => println!("Ignored unknown kwarg option {}", key),
+                    _ => println!("Ignored unknown kwarg option {key}"),
                 }
             }
         }
@@ -796,7 +795,7 @@ impl PyTokenizer {
     #[getter]
     fn get_truncation<'py>(&self, py: Python<'py>) -> PyResult<Option<Bound<'py, PyDict>>> {
         self.tokenizer.get_truncation().map_or(Ok(None), |params| {
-            let dict = PyDict::new_bound(py);
+            let dict = PyDict::new(py);
 
             dict.set_item("max_length", params.max_length)?;
             dict.set_item("stride", params.stride)?;
@@ -847,9 +846,8 @@ impl PyTokenizer {
                             "left" => Ok(PaddingDirection::Left),
                             "right" => Ok(PaddingDirection::Right),
                             other => Err(PyError(format!(
-                                "Unknown `direction`: `{}`. Use \
-                                 one of `left` or `right`",
-                                other
+                                "Unknown `direction`: `{other}`. Use \
+                                 one of `left` or `right`"
                             ))
                             .into_pyerr::<exceptions::PyValueError>()),
                         }?;
@@ -880,7 +878,7 @@ impl PyTokenizer {
                             params.strategy = PaddingStrategy::BatchLongest;
                         }
                     }
-                    _ => println!("Ignored unknown kwarg option {}", key),
+                    _ => println!("Ignored unknown kwarg option {key}"),
                 }
             }
         }
@@ -906,7 +904,7 @@ impl PyTokenizer {
     #[getter]
     fn get_padding<'py>(&self, py: Python<'py>) -> PyResult<Option<Bound<'py, PyDict>>> {
         self.tokenizer.get_padding().map_or(Ok(None), |params| {
-            let dict = PyDict::new_bound(py);
+            let dict = PyDict::new(py);
 
             dict.set_item(
                 "length",
@@ -1342,7 +1340,7 @@ impl PyTokenizer {
                 if let Ok(s) = element.downcast::<PyString>() {
                     itertools::Either::Right(std::iter::once(s.to_cow().map(|s| s.into_owned())))
                 } else {
-                    match element.iter() {
+                    match element.try_iter() {
                         Ok(iter) => itertools::Either::Left(
                             iter.map(|i| i?.extract::<String>())
                                 .collect::<Vec<_>>()
